Crate solana_rayon_threadlimit

Crate solana_rayon_threadlimit 

๐Ÿ‘ŽDeprecated since 3.1.0:

This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Functions

get_max_thread_countDeprecated
get_thread_countDeprecated